@@ -66,14 +66,18 @@ struct _BjbMainToolbar
   GtkWidget *empty_button;
   GtkWidget *color_button;
   GtkWidget *button_stack;
+  GtkWidget *main_button;
   GtkWidget *menu_button;
 
+  /* Main menu items */
+  GtkWidget *large_item;
+  GtkWidget *medium_item;
+  GtkWidget *small_item;
+
   /* Menu items */
   GtkWidget *new_window_item;
   GtkWidget *undo_item;
   GtkWidget *redo_item;
-  GtkWidget *notebook_item;
-  GtkWidget *email_item;
   GtkWidget *trash_item;
   GtkWidget *last_update_item;
 
@@ -103,6 +107,70 @@ static GParamSpec *properties[NUM_PROPERTIES] = { NULL, };
 
 G_DEFINE_TYPE (BjbMainToolbar, bjb_main_toolbar, GTK_TYPE_HEADER_BAR)
 
+static void
+on_about_cb (BjbMainToolbar *self)
+{
+  bjb_app_about (BJB_APPLICATION (g_application_get_default ()));
+}
+
+static void
+on_import_notes_cb (BjbMainToolbar *self)
+{
+  bjb_app_import_notes (BJB_APPLICATION (g_application_get_default ()));
+}
+
+static void
+on_view_trash_cb (BjbMainToolbar *self)
+{
+  GtkApplication *app = GTK_APPLICATION (g_application_get_default ());
+  GList *windows = gtk_application_get_windows (app);
+  BjbController *controller = bjb_window_base_get_controller (BJB_WINDOW_BASE (windows->data));
+
+  bjb_controller_set_group (controller, BIJI_ARCHIVED_ITEMS);
+}
+
+static void
+on_text_size_cb (BjbMainToolbar *self,
+                 GtkWidget      *item)
+{
+  BjbSettings *settings = bjb_app_get_settings (g_application_get_default ());
+  BjbTextSizeType text_size = g_settings_get_enum (G_SETTINGS (settings), "text-size");
+  BjbTextSizeType new_text_size = text_size;
+
+  if (item == self->large_item)
+    {
+      new_text_size = BJB_TEXT_SIZE_LARGE;
+    }
+  else if (item == self->medium_item)
+    {
+      new_text_size = BJB_TEXT_SIZE_MEDIUM;
+    }
+  else if (item == self->small_item)
+    {
+      new_text_size = BJB_TEXT_SIZE_SMALL;
+    }
+
+  if (text_size != new_text_size)
+    {
+      g_settings_set_enum (G_SETTINGS (settings), "text-size", new_text_size);
+    }
+}
+
+static void
+on_preferences_cb (BjbMainToolbar *self)
+{
+  GtkApplication *app = GTK_APPLICATION (g_application_get_default ());
+  GList *windows = gtk_application_get_windows (app);
+
+  show_bijiben_settings_window (g_list_nth_data (windows, 0));
+}
+
+static void
+on_help_cb (BjbMainToolbar *self)
+{
+  bjb_app_help (BJB_APPLICATION (g_application_get_default ()));
+}
+
 static void
 on_new_note_clicked (BjbMainToolbar *self)
 {
@@ -252,6 +320,7 @@ populate_bar_for_selection (BjbMainToolbar *self)
   gtk_widget_hide (self->select_button);
   gtk_widget_hide (self->button_stack);
   gtk_widget_hide (self->style_buttons);
+  gtk_widget_hide (self->main_button);
   gtk_widget_show (self->cancel_button);
 
   connect_main_view_handlers (self);
@@ -348,6 +417,7 @@ populate_bar_for_standard(BjbMainToolbar *self)
   if (bjb_controller_get_notebook (self->controller))
     {
       gtk_widget_hide (self->new_button);
+      gtk_widget_hide (self->main_button);
       gtk_widget_show (self->back_button);
     }
 
@@ -366,6 +436,7 @@ populate_bar_for_trash (BjbMainToolbar *self)
 
   gtk_widget_hide (self->new_button);
   gtk_widget_hide (self->search_button);
+  gtk_widget_hide (self->main_button);
   gtk_widget_show (self->empty_button);
   gtk_widget_show (self->back_button);
 
@@ -515,6 +586,7 @@ populate_bar_for_note_view (BjbMainToolbar *self)
   gtk_widget_hide (self->style_buttons);
   gtk_widget_hide (self->search_button);
   gtk_widget_hide (self->select_button);
+  gtk_widget_hide (self->main_button);
 
   gtk_widget_show (self->back_button);
   gtk_widget_show (self->menu_button);
@@ -565,6 +637,7 @@ bjb_main_toolbar_reset (BjbMainToolbar *self)
   gtk_widget_show (self->select_button);
   gtk_widget_show (self->search_button);
   gtk_widget_show (self->new_button);
+  gtk_widget_show (self->main_button);
 
   gtk_widget_hide (self->back_button);
   gtk_widget_hide (self->color_button);
@@ -708,6 +781,9 @@ populate_main_toolbar(BjbMainToolbar *self)
 static void
 bjb_main_toolbar_setup_menu (BjbMainToolbar *self)
 {
+  BjbSettings *settings = bjb_app_get_settings (g_application_get_default ());
+  BjbTextSizeType text_size = g_settings_get_enum (G_SETTINGS (settings), "text-size");
+
   gtk_widget_add_accelerator (self->undo_item, "activate", self->accel, GDK_KEY_z,
                               GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
   gtk_widget_add_accelerator (self->redo_item, "activate", self->accel, GDK_KEY_z,
@@ -715,6 +791,11 @@ bjb_main_toolbar_setup_menu (BjbMainToolbar *self)
   gtk_widget_add_accelerator (self->trash_item, "activate", self->accel,
                               GDK_KEY_Delete, GDK_CONTROL_MASK,
                               GTK_ACCEL_VISIBLE);
+
+  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (self->large_item), text_size == BJB_TEXT_SIZE_LARGE);
+  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (self->medium_item), text_size == BJB_TEXT_SIZE_MEDIUM);
+  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (self->small_item), text_size == BJB_TEXT_SIZE_SMALL);
+
 }
 
 static void
@@ -850,13 +931,18 @@ bjb_main_toolbar_class_init (BjbMainToolbarClass *klass)
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, cancel_button);
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, select_button);
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, color_button);
+  gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, main_button);
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, menu_button);
 
+  /* Main menu items */
+  gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, large_item);
+  gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, medium_item);
+  gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, small_item);
+
+  /* Menu items */
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, new_window_item);
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, undo_item);
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, redo_item);
-  gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, notebook_item);
-  gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, email_item);
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, trash_item);
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, last_update_item);
 
@@ -867,6 +953,15 @@ bjb_main_toolbar_class_init (BjbMainToolbarClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, on_empty_clicked_callback);
   gtk_widget_class_bind_template_callback (widget_class, on_color_button_clicked);
 
+  /* Main menu items */
+  gtk_widget_class_bind_template_callback (widget_class, on_import_notes_cb);
+  gtk_widget_class_bind_template_callback (widget_class, on_view_trash_cb);
+  gtk_widget_class_bind_template_callback (widget_class, on_preferences_cb);
+  gtk_widget_class_bind_template_callback (widget_class, on_help_cb);
+  gtk_widget_class_bind_template_callback (widget_class, on_about_cb);
+  gtk_widget_class_bind_template_callback (widget_class, on_text_size_cb);
+
+  /* Menu items */
   gtk_widget_class_bind_template_callback (widget_class, on_detached_clicked_cb);
   gtk_widget_class_bind_template_callback (widget_class, on_undo_or_redo_cb);
   gtk_widget_class_bind_template_callback (widget_class, action_view_tags_callback);
